# -*- coding: utf-8 -*-

__title__ = 'PyCEP Correios'
__version__ = '1.1.5'
__author__ = 'Michell Stuttgart Faria'
__license__ = 'MIT'
__copyright__ = 'Copyright 2015-2017 Michell Stuttgart Faria'

# Version synonym
VERSION = __version__
